# -*- encoding: utf-8 -*-
#

"""
This is Wombat, an operations and maintenance tool for Erlang systems
© 2015, Erlang Solutions Ltd
"""

class Alarm(object):
    """This calss represents an active alarm in Wombat."""

    def __repr__(self):
        data = self.__dict__.copy()
        del data['wombat']

        return 'Alarm({!r}, {!r})'.format(self.wombat, data)

    def __str__(self):
        return '{!s} alarm on {!s}'.format(self.alarmId, self.src['nodeName'])

    def __init__(self, wombat, data):
        self.wombat = wombat
        self.__dict__.update(data)

    def get_node(self):
        """Return the Node object to which this alarm belongs."""
        return Node(self.wombat, self.src['nodeId'])

    def acknowledge(self, user = None):
        """Acknowledge the alarm.

        The user defaults to the user name used for authenticating
        towards Wombat but can be customised.

        """
        self.wombat.acknowledge_alarm(alarm = self, user = user)

    def unacknowledge(self, user = None):
        """Unacknowledge the alarm.

        The user defaults to the user name used for authenticating
        towards Wombat but can be customised.

        """
        self.wombat.unacknowledge_alarm(alarm = self, user = user)

    def clear(self, user = None):
        """Clear the alarm.

        The user defaults to the user name used for authenticating
        towards Wombat but can be customised.

        """
        self.wombat.clear_alarm(alarm = self, user = user)

    def comment(self, message, user = None):
        """Comment on the alarm.

        The user defaults to the user name used for authenticating
        towards Wombat but can be customised.

        """
        self.wombat.comment_alarm(message = message, alarm = self, user = user)
