# -*- encoding: utf-8 -*-
#

"""
This is Wombat, an operations and maintenance tool for Erlang systems
© 2015, Erlang Solutions Ltd
"""

from __future__ import absolute_import

from wombat.wombat_object import WombatObject

class Node(WombatObject):
    """This class represents a node managed by Wombat."""

    def __init__(self, wombat, id, data = None):
        WombatObject.__init__(self, wombat, id, 'topo/node/{}')

    def get_node_family(self):
        """Return the NodeFamily object to which this node belongs."""
        return NodeFamily(self.wombat, self.node_family_id)

    def get_metric_info(self):
        """Get metadata for all known metrics on the node."""
        return self.wombat.get_metric_info(node = self.id)

    def get_gauge_info(self):
        """Get metadata for gauges defined on the node."""
        return self.wombat.get_gauge_info(node = self.id)

    def get_metric(self, metric_id, metric_type, from_time, to_time,
                   series = 1):
        """Fetch metric samples for a metric in the given time interval.

        The return value is a list of samples.

        """

        return self.wombat.get_metric(metric_id, metric_type, from_time,
                                      to_time, series, node = self.id)

    def enum_logs(self, originator = None):
        """Return a generator for enumerating logs from the node.

        It is possible to enumerate only logs coming from a given
        originator.

        """
        return self.wombat.enum_logs(node = self.id, originator = originator)

    def get_log_originators(self):
        """Return the list of all log originators available for filtering the
        notifications on the node.

        """
        return self.wombat.get_log_originators(node = self.id)

    def get_log_levels(self):
        """Return a dictionary mapping handlers to log levels on the node."""
        return self.wombat.get_log_levels(self.id)

    def set_log_level(self, handler, level):
        """Update the log level for the specified handler on a node."""
        self.wombat.set_log_level(self.id, handler, level)

    def enum_alarms(self, source = None, following = None):
        """Return a generator for enumerating alarms on the node.

        When no arguments are provided, all active alarms on the node
        are considered. But it is possible to filter for a specific
        alarm source or to enumerate only alarms following a given
        event.

        """
        return self.wombat.enum_alarms(node = self.id,
                                       source = source,
                                       following = following)

    def get_alarm_sources(self):
        """Return the list of all alarm sources available for
        filtering the alarms on the node.

        """
        return self.wombat.get_alarm_sources(node = self.id)

    def get_plugins(self):
        """Get the state of plugins on the managed node.

        The result is a dictionary mapping plugin names to plugin
        data.

        """
        return self.wombat.get_plugins(node = self.id)

    def set_plugin_state(self, plugin, state):
        """Set the state of a plugin or all plugins on the managed node.

        The state should be 'on' or 'off'. If plugin is a string, only
        that plugin's state will be changed. But it can also be None,
        in which case all plugins are affected.

        """
        self.wombat.set_plugin_state(self.id, plugin, state)

    def delete(self):
        """Remove the node from being managed in Wombat."""
        self.wombat.delete_node(node = self.id)
