# -*- encoding: utf-8 -*-
#

"""
This is Wombat, an operations and maintenance tool for Erlang systems
© 2015, Erlang Solutions Ltd
"""

from __future__ import absolute_import

from wombat.wombat_rest import quote_path

class WombatObject(object):
    """This class represents an object living on a WombatOAM instance.

    When created, a WombatObject is tied to the WombatOAM instance on
    which it exists and an id. It also has an url from which the
    object's properties can be queried.

    If an object is initialized without data or when the refresh()
    function is called, it will reload its properties from the Wombat
    server. In this case an exception is thrown if the object does not
    exist.

    """

    def __repr__(self):
        return '{}({!r}, {!r})'.format(self.__class__.__name__,
                                       self.wombat,
                                       self.id)

    def __str__(self):
        if self.__dict__.has_key('name'):
            return '{} {!s} ({!s})'.format(self.__class__.__name__,
                                           self.name, self.id)
        else:
            return '{} {!s}'.format(self.__class__.__name__, self.id)

    def __init__(self, wombat, id, url, data = None):
        """Initialize the object."""
        self.wombat = wombat
        self.id = id
        self.url = url

        if data:
            self.__refresh_with_data(data)
        else:
            self.refresh()

    def refresh(self):
        """Reload the object's properties from the Wombat server."""
        data = self.wombat.get(self.url.format(quote_path(self.id)))
        self.__refresh_with_data(data)

    def __refresh_with_data(self, data):
        if not self.id == data.get('id'):
            raise WombatException(
                'Error getting data from {} {}. Reason: ' \
                'invalid id {}'.format(self.__class__.__name__,
                                       self.id,
                                       data.get('id', '(none)')))

        self.__dict__.update(data)
