How to demo Wombat
==================

Preparation
-----------

Note: the README contains useful information about Wombat (like where to find
the logs).

### 1. Build and start Wombat

    git clone git@github.com:esl/wombat.git
    cd wombat
    git checkout master
    make rel    # build the release
    make start  # start Wombat
    make stop   # stop Wombat

Open http://localhost:8080/ to see the web interface.

Another option is to use the latest binary release (see the [Installing from a
package][package] section of the README), but not everything below is
in the packaged release (e.g. the `test-env` directory that handles the test
nodes is not in the package.)

[package]: https://github.com/esl/wombat/blob/dev/README.md#installing-from-a-package

### Set user.config

A few useful settings to add to `rel/wombat/files/user.config`:

    [
     {wo_dashboard, [
                     % Let's make the Orchestration tab visible.
                     {enable_orch, true},

                     % Let's use HTTP.
                     {enable_force_ssl, false}
                    ]},

     {wo_core, [
                % So that we don't have to wait half a minute on the demo for
                % Wombat to discover that a node is up again.
                {node_monitor_max_wait, 3000}
               ]},

     {wo_metrics, [
                   {graphite, [
                               {carbon_host, "127.0.0.1"},
                               {carbon_transport, udp},
                               {carbon_port, 2003}
                              ]}
                  ]},

     {wo_rest, [
        % Let's not use authentication.
        {enable_authentication, false}
     ]}

    ].

See more details in the [Configuration section of the README][readme-config].

[readme-config]: https://github.com/esl/wombat-docs/blob/master/configuration.md

### 2. Start test nodes

Start 6 test nodes:

    for i in {1..6}; do test-env/go.sh wo_test_$i@127.0.0.1 cookietest; done

Join 1-3 and 4-6:

    for i in {1..2}; do test-env/join.sh wo_test_$i@127.0.0.1 wo_test_$(($i+1))@127.0.0.1 cookietest; done
    for i in {4..5}; do test-env/join.sh wo_test_$i@127.0.0.1 wo_test_$(($i+1))@127.0.0.1 cookietest; done

Add nodes 1-3 and wombat itself to Wombat:

    curl -X POST \
         -H 'Content-Type: application/json' \
         -H 'Accept: application/json' \
         http://localhost:8080/api/topo/action/add-node-and-disc \
         -d '{"name":"wo_test_1@127.0.0.1", "cookie": "cookietest"}'
    curl -X POST \
         -H 'Content-Type: application/json' \
         -H 'Accept: application/json' \
         http://localhost:8080/api/topo/action/add-node-and-disc \
         -d '{"name":"wombat@127.0.0.1", "cookie": "wombat"}'

As an alternative to using `curl` you can use the Python CLI:

    (cd scripts && git clone git@github.com:esl/pywombat.git pywombat)
    for i in {1..3}; do
        PYTHONPATH=scripts/pywombat python3 -m wombat add node wo_test_${i}@127.0.0.1 cookietest
    done
    PYTHONPATH=scripts/pywombat python3 -m wombat add node wombat@127.0.0.1 wombat

Later you can stop the test nodes with the following command:

    for i in {1..6}; do test-env/stop.sh wo_test_$i@127.0.0.1 cookietest; done

### 3. Start Graphite

- If you want to demo Graphite, [configure Wombat to push the metrics into
  Graphite][graphite].
- Delete the Graphite database (`rm -r graphite/storage/whisper`).
- Start carbon and Graphite.

[graphite]: https://github.com/esl/wombat/blob/dev/README.md#configuring-graphite

### 4. Wait

Let the nodes run for an hour before the demo so that they produce some metrics.

Demo
----

### Topology (adding and deleting nodes)

- Add a node: `wo_test@127.0.0.1`, cookie: `wo_test`.
- Add a node with discovery: `wo_test_4@127.0.0.1`, cookie: `cookietest`.
- Delete nodes: delete `wo_test_6`
- Show plugin controls: turn off the `code_tracer` for `wo_test@127.0.0.1`

### Metrics

- Show built-in metrics
- Show different time intervals (15-minutes, daily, weekly)
- Show over imposing metrics, e.g. total memory vs other memory types
- Show family metrics
- Show folsom metrics
- Show Graphite

### Notifications

**Note** about demoing notifications and alarms: When notifications
and alarm come in to the dashboard, only the counter badges next to
the "Notifications" and "Alarms" tab are incremented. Popups are no
longer shown.

New notifications won't turn up immediately on the Notifications
tab. Instead a _New logs have arrived. Click here to see them._
message appears above the logs. **Do not click the link** when looking
at a node or node family: it will reset the filter to all logs, but
leave the node/family highlighted on the left tree view. Click on the
node/family name instead. (This is bug
[#1680](https://github.com/esl/wombat/issues/1680).)

We added the `wo_test` this node in the beginning of the demo, so we use this
node for alarms. This node does not have any old notifications/alarms.

Attach to the `wo_test` node:

    rel/wo_test/wo_test/bin/wo_test attach

`error_logger` notification:

    error_logger:error_msg("My error").

`lager` log entry:

    lager:log(error, self(), "Lager log entry").

A process crash:

    wo_test_crash_sup:new_child().
    wo_test_crash_sup:crash_child().

Set lager log level to `info` and issue: (the log will not be shown
automatically, we need to e.g. click on another node and click back)

    lager:log(info, self(), "Lager log entry").

Go back to the topology tab and reenable the `code_tracer`
plugin. Execute some commands in the shell and see there are
notifications generated based on these actions:

    code:add_path("../../../apps/wo_utils/ebin").
    l(wo_utils).

This will generate two kind of notifications, both documenting typical
events that may lead to hard to debug problems in production systems:

- Shell: Command evaluated
- Module checker: Module loaded

Handle notifications on the web dashboard:

- Search
- Application filter

### Alarms

`node_down` alarm (immediate):

    rel/wo_test/wo_test/bin/wo_test stop
    rel/wo_test/wo_test/bin/wo_test start

`atom_limit alarm` (in 10 seconds):

    [list_to_atom(integer_to_list(X)) || X <- lists:seq(1, 900000)].

`old_code` alarm (in 10 seconds):

    l(lists).

`process_message_queue` alarm (in 1 minute):

    [self() ! ping || _ <- lists:seq(1,25000)].

    % Clear:
    flush().

`shell_history_size` (in 1 minute):

    L = lists:seq(1, 5000000).

    % Clear:
    f(), [erlang:garbage_collect(P) || P <- processes()].

`alarm_handler` alarms:

    alarm_handler:set_alarm({myalarm, "This is my alarm"}).
    alarm_handler:clear_alarm(myalarm).

`elarm` alarms:

    elarm:raise(myelarm, "Demo", []).
    elarm:clear(myelarm, "Demo").

Handle alarms on the web dashboard:

- Open all, close all
- Acknowledge
- Comment
- Clear

### Orchestration

The best is to show the ["Deploying Erlang nodes with Wombat" video][video].

[video]: http://vimeo.com/85243629
