# Wombat troubleshooting guide

## Cowboy crashes when the web browser sends something funny

**Problem:**

When trying loading the Wombat dashboard, the browser says "No data received",
and the following entry appears in the lager log:

    2014-04-04 15:52:30.348 [error] emulator Error in process <0.1417.0> on node 'wombat@127.0.0.1' with exit value: {function_clause,[{cowboy_http,quoted_string,[<<9 bytes>>,#Fun<cowboy_http.21.12350283>],[{file,"src/cowboy_http.erl"},{line,763}]},{cowboy_http,nonempty_list,2,[{file,"src/cowboy_http.erl"},{line,61}]},{cowboy_req,parse_header,4,[{file,"src/cowboy_req.erl"},{line... 

**Reason:**

The most probable reason is that the browser sends an unquoted [ETag][1],
which Cowboy cannot parse. This can happen if you had recently run a
different webserver on the same port serving the same resource
(e.g. `http://localhost:8080/`, which is quite common) with an
unquoted ETag. As long as that page is in the browser's cache, the
browser will send the problematic ETag along with all the requests.

**Solution:**

[Some][2] [Googling][3] revealed that clearing the browser cache solves the
problem. For me, loading it in another browser and then again in Chrome (with
the Network tab open) also made the error disappear.

You can also easily verify caching-related problems by loading the
page in an incognito tab. In that case the browser will not use any of
its cached resources, cookies etc.

## Strange node add problem on Safari

**Problem**

When trying to add a node in a way that type the first letter of the node (let
it be `w`) and Safari auto-complete the other characters (since it has been
added to Wombat earlier) and don't press enter but click somewhere else to
enter the cookie, node add will fail.

Checking the logs you can see something like that:

```
2014-05-12 14:44:54.435 [warning] <0.1632.0> [wo_node_disc_lib:223] Node is not reachable: w (Cookie=wo_test)
2014-05-12 14:44:54.435 [warning] <0.1632.0> [wo_node_disc_lib:73] Could not add node w (Reason: not_reachable)
2014-05-12 14:44:54.435 [info] <0.1631.0> [wo_topo_rest_handler:246] An error has occurred ( not_reachable )
```

**Solution**

Bootstrap UI and Safari auto-complete cannot work with together. You need to
edit the node name manually in order that Bootstrap can detect the change.
Then you can press the button to add node to Wombat.

## Node doesn't come UP even though it is running again

**Problem**

I added Riak nodes to Wombat, stopped them, started them; but their change
didn't change to UP. The Riak logs said contained the following error report
every time the Wombat node managers were trying to connect:

```
2014-07-07 17:31:19 =ERROR REPORT====
** Connection attempt from disallowed node 'wombat@127.0.0.1' **
```

**Reason**

The reason is not entirely clear. The Wombat node somehow forgot the cookie of
the Riak nodes. The `wo_node_monitor` processes were running fine, and since the
database contained the correct cookie (`riak`), it must have called
`erlang:set_cookie('riak1@127.0.0.1', riak)` in its `init` function. But when we
checked the cookie that it uses to connect to the Riak nodes, it was the default
one:

```
> auth:get_cookie('riak1@127.0.0.1').
wombat
```

[1]: http://en.wikipedia.org/wiki/HTTP_ETag
[2]: https://groups.google.com/forum/#!topic/nitrogenweb/RRhKt58iI50
[3]: https://groups.google.com/forum/#!msg/chicagoboss/_CiwCWLWhk4/qHsEovOzb1QJ
