# Creating Docker images containing WombatOAM

The `scripts/docker/make_docker_image.sh` creates a Docker image containing
WombatOAM. The base of the Docker image is the official Debian/jessie image
(see [The Docker Hub](https://hub.docker.com/_/debian/) for details). Debian
updates are installed (possibly unnecessary as the base Debian image is
updated when security fixes are made) along with the `wget` and `openssl`
packages (these are required for the next step). Then 18.3.4 Erlang/OTP is
installed from the Erlang Solutions repository. The next step is to copy the
wombat release (and optionally the license key file) into the container and
install Wombat.

For parameters and usage instructions execute
```
make_docker_image.sh --help
```

By default the script only creates the image file with a license and prints
instructions on how to load and start it. An example:
To start the created Docker image, use the
```
  docker run -tid -p 8080:8080 --name wombat-2.2.3 wombat:2.2.3
```
command.
To "login" to the running Docker image, use the
```
  docker exec -i -t wombat-2.2.3 /bin/bash
```
command.
To stop the Docker image, use the
```
  docker stop wombat-2.2.3
```
command.
To remove the Docker image from the system, use the
```
  docker container rm wombat-2.2.3
  docker image rm wombat:2.2.3
```
commands. Use the first command only if the image was started at least once.

A useful command to "connect" to (look into) the running container is
```
docker exec -i -t wombat-2.2.3 /bin/bash
```
This command starts a (root) shell inside the container.

## Creating Docker image without license

With the -n option it is possible to create a Docker image that does not
contain a license. Instead, it contains the `/wombat-<version>/lic_dir`
directory and the `license.lic_key` in the `/wombat-<version>` directory
is a symlink into this directory. This way when the Docker image is started,
a directory from the host can be bind mounted to the
`/wombat-<version>/lic_dir` directory and this directory on the host should
contain the license key file. An example to create and keep the image:
```
./make_docker_image.sh -v 2.3.0 -t ~/wombat-2.3.0.tar.gz -i wombat.docker -n -k
```
Then to start the image:
```
docker run -tid -p 8080:8080 -v /home/nar/wombat/scripts/docker/lic_dir:/wombat-2.3.0/lic_dir --name wombat-2.3.0 wombat:2.3.0
```
The `/home/nar/wombat/scripts/docker/lic_dir` directory has to contain the
license key file. This generated image is not customer-specific, so it can be
released to e.g. DockerHub:
```
docker login
docker tag wombat:2.3.0 attilanohl/wombatoam:latest
docker push attilanohl/wombatoam
```

There is a Docker image created this way from WombatOAM 2.3.0 on DockerHub. The
image can be downloaded with this command:
```
docker pull attilanohl/wombatoam
```


