## Using Wombat Orchestration with curl

> **Remember!**
>
> If you are using the default Wombat settings, `<WOMBATOAM_REST_SERVICE>` maps to localhost:8888.

First, you need to **upload the tarball** containing the Wombat-compliant Erlang release.

```sh
curl -H "Content-Type: application/json"
     -H "Accept: application/json"
     -X POST http://<WOMBATOAM_REST_SERVICE>/api/release
     -d '{"name": <RELEASE_NAME>,
          "description": <RELEASE_DESCRIPTION>,
          "tarball": "'`base64 \path\to\the\release\tarball.tar.gz`'"}'
```

However, if you have already tried to execute the above command, you will have most-likely got an *"argument list too long"* error due to the length of the base64 encoded tarball.
This can be sorted out by creating a file containing the request body and replace the value of the -d flag to

```sh
-d @/path/to/the/file/containing/the/request/body.json
```

The next step is to **register an infrastructure provider** (e.g. Amazon EC2).

```sh
curl -H "Content-Type: application/json"
     -H "Accept: application/json"
     -X POST http://<WOMBATOAM_REST_SERVICE>/api/provider
     -d '{"name": <PROVIDER_NAME>,
          "description": <PROVIDER_DESCRIPTION>,
          "username": <USERNAME_TO_AUTHENTICATE_WITH_THE_PROVIDER>,
          "password": <PASSWORD_TO_AUTHENTICATE_WITH_THE_PROVIDER>,
          "endpoint": <DELTACLOUD_SERVIVE_URL>}'
```

> **Test deployment**
>
> To carry out a local deployment (all nodes are deployed on the same machine as Wombat itself), the following bare-metal infrastructure provider must be registered instead.
> ```sh
> curl -H "Content-Type: application/json"
>      -H "Accept: application/json"
>      -X POST http://<WOMBATOAM_REST_SERVICE>/api/provider
>      -d '{"name": <PROVIDER_NAME>,
>           "description": <PROVIDER_DESCRIPTION>,
>           "hosts": ["127.0.0.1"]}'
> ```

Once you got both the release and the provider registered in the system, you can proceed to **create the node family** where the nodes
of your distributed Erlang application will be deployed on.

```sh
curl -H "Accept: application/json"
     -H "Content-Type: application/json"
     -X POST http://<WOMBATOAM_REST_SERVICE>/api/node-family
     -d '{"name": <NODE_FAMILY_NAME>,
          "description": <NODE_FAMILY_DESCRIPTION>,
          "release_id":<RELEASE_UUID>,
          "domains":
            [{"provider_id": <PROVIDER_UUID>,
              "ssh_username": <SSH_USERNAME>,
              "hw_profile": <INSTANCE_TYPE_ID>,
              "virtual_disk": <AMI_ID>,
              "firewall": {
                "id": <FIREWALL_ID>,
                "rules":
                  [{"protocol": "tcp",
                    "port_from": "22",
                    "port_to": "22"},
                   {"protocol": "tcp",
                    "port_from":"4369",
                    "port_to":"4369"},
                   {"protocol":"tcp",
                    "port_from":"9100",
                    "port_to":"9105"}]}}]}'
```

Reached this point, you are ready to **deploy your node(s)**.

```sh
curl -H "Accept: application/json"
     -H "Content-Type: application/json"
     -X POST http://<WOMBATOAM_REST_SERVICE>/api/node-family/<NODE_FAMILY_UUID>/domain/<DOMAIN_UUID>/node
     -d '{"amount": <AMOUNT_OF_NODES_TO_BE_DEPLOYED>}'
```

Finally, **start all deployed nodes** and get ready to interact with your application.

```sh
curl -H "Accept: application/json"
     -H "Content-Type: application/json"
     -X POST http://<WOMBATOAM_REST_SERVICE>/api/node-family/<NODE_FAMILY_UUID>/domain/<DOMAIN_UUID>/node/start
```
