## Creating a release file

The following modifications are required to make a standard Erlang release file
(`*.tar.gz`) deployable by Wombat:

1. Edit vm.args and replace the hard coded node name with the string
   `{{ node_name }}`. The release should not contain a hard coded node name
   anywhere else.
2. Narrow down the TCP ports allocated for distributed Erlang traffic.
   Otherwise, the node will be unmanageable at the firewall level.
3. If needed, add a bootstrap script (name and location of your choice).

D6.5 contains some more information about these steps.

## Deploying a release locally

### 1. Register infrastructure provider

- Wombat web dashboard → Orchestration → Infrastructure Providers →
  New Provider
- Physical
- name: `prov_local`
- host: `127.0.0.1`

### 2. Upload a release

- Releases tab → New release
- Name: `rel_riak_mac`
- Start command: `bin/riak start`
- Stop command: `bin/riak stop`
- Cookie: `riak`
- vm.args: `etc/vm.args`
- File: `riak_mac.tar.gz`
  ([download](https://www.dropbox.com/s/t2fkmoasad6r0o0/riak_mac.tar.gz))
- (This uploads the release to /tmp/wombat/orch/releases/ by default.)

### 3. Create a node family

- Node families tab → New Family
- Name: `riak_family_1`
- Release: `rel_riak_mac`
- Add domain

  - Infrastructure provider: `prov_local`
  - SSH user: your own user.

    MAKE SURE `ssh localhost` WORKS WITHOUT PASSWORD!

    - Only on Mac: System preferences → Sharing → [x] Remote login.
    - Run `ssh-keygen` and hit "enter" a few times.
    - Append the content of the generated public key (`~/.ssh/id_rsa.pub` by
      default) to `~/.ssh/authorized_keys`.

  - Virtual disk: ami-0cdf4965
  - Hardware profile: m1.medium
  - Click on "Add domain"

- Firewall rules: leave blank
- Node selection strategy: Random
- Bootstrapping strategy: Custom
- Bootstrapping options: `cmd:bin/bootstrap`

### 4. Nodes: Deploy node

- Node family: `riak_family_1`
- Amount: 1
- [x] Automatically start node(s) after deployment
- This will create a new directory with the release uuid in your home.
- You need to refresh your browser to see the updates in the states of the
  nodes.
- Check wombat.log.

### TODO:

- Create a mac Riak release which contains the bootstrap script.

## Deploying a release on Amazon

### 1. Install deltacloud

- On Mac: install it as described in this [OSX deltacloud
  HOWTO][osx-deltacloud-howto].

  If the compilation fails, probably you don't have the XCode command line
  tools. Install them with `xcode-select --install`.

### 2. Make sure Wombat can start deltacloud.

- By default, Wombat will just start it by executing
  `os:cmd("deltacloudd ...")`. If that doesn't work, you may need something
  like I did, see below.

- I created a `~/delta` script:

        #!/bin/bash

        export PATH=$HOME/.rbenv/shims:$PATH
        cd /path/to/deltacloud/server
        /bin/deltacloudd "$@"

- I added the following to `rel/wombat/files/sys.config`:

        {wo_orch, [{deltacloud_path, "/Users/hcs/delta"}, ...]}

### 3. Check the Amazon Web Console.

- Go to https://console.aws.amazon.com/console/home and log in.
- username: see "ESL AWS username" in secrets.txt
- password: see "ESL AWS password" in secrets.txt
- Select "EC2".
- Select "Key Pairs". Check that "wombat" with the correct fingerprint (see
  secrets.txt) is among them.
- Create the SSH keys wombat.pub and wombat (the latter with `rw-------` rights)
  in `~/.ssh`.

### 4. Register infrastructure provider

- Wombat web dashboard → Orchestration → Infrastructure Providers → New Provider
- Amazon EC2
- name: `prov_amazon`
- username: see "ESL AWS access key" in secrets.txt
- password: see "ESL AWS access code" in secrets.txt
- (These are not the actual username and password but access keys. You can
  create new access keys in ASW console → Username → Security credentials →
  Access keys.)
- Check wombat.log.
- Check that the deltacloud daemon has actually been started:

        $ ps auxww | grep deltacloud
        hcs  7041   0.0  0.0  2442000    640 s016  S+    5:01pm   0:00.00 grep --color=auto deltacloud
        hcs  7029   0.0  1.1  2544524  89900   ??  S     5:00pm   0:02.01 thin server (localhost:5000) [deltacloud-ec2]

### 5. Upload a release

- Releases tab → New release
- Name: `rel_riak_ubuntu`
- Start command: `bin/riak start`
- Stop command: `bin/riak stop`
- Cookie: `riak`
- vm.args: `etc/vm.args`
- File: `riak_ubuntu.tar.gz`
  ([download](https://www.dropbox.com/s/664urf6i04p7sqn/riak_ubuntu.tar.gz))
- (This uploads the release to /tmp/wombat/orch/releases/ by default.)

### 6. Create a node family

- Node families tab → New Family
- Name: `riak_family_2`
- Release: `rel_riak_ubuntu`
- Add domain
  - Infrastructure provider: `prov_amazon`
  - SSH user: ubuntu
  - Virtual disk: ami-0cdf4965
  - Hardware profile: m1.small / t1.micro
  - Click on "Add domain"
- Firewall rules: tcp:4369:4369,tcp:8097:8099,tcp:8087:8087,tcp:8069:8069,tcp:6000:7999
- Node selection strategy: Random
- Bootstrapping strategy: Custom
- Bootstrapping options: cmd:bin/bootstrap
- Check wombat.log.

### 7. Nodes: Deploy node

- Node family: `riak_family_2`
- Amount: 2
- [x] Automatically start node(s) after deployment
- Check wombat.log.

### 8. Go to the AWS console → Instances → You should see the new VMs.

### 9. Log in to the VM to see that it is running

- Log in:

        $ ssh -i ~/.ssh/wombat ubuntu@ec2-54-242-253-9.compute-1.amazonaws.com

- Test that Riak is running on the machine:

        $ ps auxww | grep riak

- If several Riak machines were deployed, you could also test that they are
  connected:

        $ ~/*/bin/riak-admin ring-status

### 10. Delete the VMs.

Two very important things:

> - BE VERY CAREFUL!!! WE ALSO HAVE PRODUCTION MACHINES IN AMAZON!!!
> - Don't miss this step, because the more these servers run, the more company
>   pays.

- Go to the AWS console → Instances → Select the VM(s) → Actions → Actions →
  Terminate.

[osx-deltacloud-howto]: https://cwiki.apache.org/confluence/display/DTACLOUD/Deltacloud+API+development+setup+on+OSX
