Bookmark REST interface
=============================

- [Create bookmarks](#create-bookmarks)
- [Read all bookmarks](#read-all-bookmarks)
- [Update bookmarks](#update-bookmarks)
- [Delete bookmarks](#delete-bookmarks)


Create bookmarks
----------------

Create bookmark entries in WombatOAM, by sending a JSON array in the
"bookmark" JSON object, all of which is within the HTTP request body.
This array can contain one or more bookmark entries to be created.

### Definition

```http
PUT /api/bookmark
```

### Example request

```
curl -u admin:admin --insecure -v -H "Content-Type:application/json" -X PUT \
"https://127.0.0.1:8443/api/bookmark" \
-d "{\"bookmarks\": [{\"title\": \"title\",\"url\": \"url1\"},{\"title\": \"title2\",\"url\": \"url2\"}]}"
```

### Example request body

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Example response

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Arguments

**Argument** | **Description**
------------ | ---------------
**bookmarks** | **Required.**

### Returns

All the bookmarks currently created in WombatOAM.
The JSON response is a "bookmarks" object with an array of bookmark arrays.


Read all bookmarks
------------------

Retrieve all the existing bookmarks created in WombatOAM.

### Definition

```http
GET /api/bookmark
```

### Example request

```
curl -u admin:admin --insecure -v /api/bookmarks -X GET "https://127.0.0.1:8443/api/bookmark"
```

### Example response

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Returns

All the bookmarks currently created in WombatOAM.
The JSON response is a "bookmarks" object with an array of bookmark arrays.


Update bookmarks
----------------

Update/create one or more bookmark entries in WombatOAM.

### Definition

```http
POST /api/bookmark
```

### Example request

```
curl -u admin:admin --insecure -v -H "Content-Type:application/json" -X POST \
"https://127.0.0.1:8443/api/bookmark" \
-d "{\"bookmarks\": [{\"title\": \"Newtitle\",\"url\": \"Newurl1\"},{\"title\": \"title2\",\"url\": \"url2\"}]}"
```

### Example request body

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Example response

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Arguments

**Argument** | **Description**
------------ | ---------------
**bookmarks** | **Required.**

### Returns

All the bookmarks currently created in WombatOAM.
The JSON response is a "bookmarks" object with an array of bookmark arrays.


Delete bookmarks
----------------

Delete one or more bookmark entries in WombatOAM.

### Definition

```http
DELETE /api/bookmark
```

### Example request

```
curl -u admin:admin --insecure -v -H "Content-Type:application/json" -X DELETE "https://127.0.0.1:8443/api/bookmark" -d "{\"bookmarks\": [{\"title\": \"title\",\"url\": \"url1\"},{\"title\": \"title2\",\"url\": \"url2\"}]}"
```

### Example request body

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Example response

```json
{
    "bookmarks":[
        {"title":"My-Bookmark",
         "url":  "https://localhost:8443/#/metrics?f=0&n=0&mtype=default&metrics=&mcat=1"},
        {... : ...},
        ...
    ]
}
```

### Arguments

**Argument** | **Description**
------------ | ---------------
**bookmarks** | **Required.**

### Returns

All the bookmarks currently created in WombatOAM.
The JSON response is a "bookmarks" object with an array of bookmark arrays.
