# Using Docker images containing WombatOAM

You should already have access to the Docker image we created, if not, please get
in touch.
The base of the Docker image is the official Erlang 17.5 built by Docker (erlang:17.5-slim)
(see [The Docker Hub](https://hub.docker.com/_/debian/) for details).
The prebuilt Docker image is also  available on DockerHub, please contact your
Erlang Solutions sales representative or wombat@erlang-solutions.com for the access details.

Due to limitations in the Erlang VM currently it's not possible to connect to nodes
which are not in the same network as the Wombat container (as in, only exposing ports).
Use `docker-compose` or `docker stack` overlay networks or similar solutions
to start containers in the same network.

## Starting WombatOAM in Docker for the first time


By default the script only creates the image file with a license and prints
instructions on how to load and start it. An example:

1. Import the image locally by running
    <pre>```
      docker load --input wombat_<version>.image.tar
    ```</pre>
2. To start the created Docker image, use the
    <pre>```
      docker run -tid -p 8080:8080 --name wombat-2.9.0 wombat:<version>
    ```</pre>
command. This will create and start a container with `wombat-2.9.0` from the
`wombat:2.9.0` image.

If you wish to use a Docker image file not containing a license key, then a
directory containing the license key has to be mounted:
```
  docker run -tid -p 8080:8080 \
  -v $PWD/lic_dir:/wombat-2.9.0/lic_dir \
  --name wombat-2.9.0 wombat:2.9.0
```

If you wish to store the logs and the data on the host, outside the Docker
container, then two directories have to be mounted, one for the data and
one for the logs:
```
  docker run -tid -p 8080:8080 \
  -v $PWD/data:/wombat-2.9.0/rel/wombat/wombat/data \
  -v $PWD/log:/wombat-2.9.0/rel/wombat/wombat/log \
  --name wombat-2.9.0 wombat:2.9.0
```

## Starting already created container

If the Docker container is already created, just use
```
  docker start wombat-2.9.0
```

## Stopping a running container

To stop the Docker container, use the
```
  docker stop wombat-2.9.0
```
command.

## Removing the container and the image

To remove the Docker container and image from the system, use the
```
  docker container rm wombat-2.9.0
  docker image rm wombat:2.9.0
```
commands.

## Starting PyWombat commands

To start the `wombat_cli` command, use the
```
  docker exec -i -t wombat-2.9.0 /usr/local/bin/wombat_cli
```
command. In integrations using `wombat_cli`, `wombat_check` or
`wombat_zabbixplugin` ([Cacti][cacti_int], [Nagios][nagios_int],
[Zabbix][zabbix_int]) you have to use a command like above instead of the
simple `/usr/local/bin/wombat_cli`.

## Useful commands

To "connect" to (look into) the running container, use the
```
docker exec -i -t wombat-2.9.0 /bin/bash
```
command. This command starts a (root) shell inside the container.

[pywombat_int]: integration.md#pywombat
[cacti_int]: integration.md#integration-with-cacti
[nagios_int]: integration.md#integration-with-nagios
[zabbix_int]: integration.md#integration-with-zabbix
