## Ejabberd plugin

### Description

This plugin reports metrics of an Ejabberd node. It can be used to
monitor a server. It does not report any alarms.

See the [XMPP specification][xmpp_spec] for more information about the XMPP
protocol, specifically about the different stanza-types (*iq, presence, message*).

### Applications it depends on

`ejabberd` <br>
All metrics are compatible with Ejabberd versions `17.03` and newer. The backwards
compatibility of the `registered_users` metric is heavily dependent on the auth
backend used by the Ejabberd instance. Support for different databases varies between
versions, consult the [Ejabberd documentation][ejabberd_docs] or source code to
ensure compatibility.

### Modules
`wombat_plugin_ejabberd`.

### Reports

This plugin only reports metrics.

#### Metrics reported
One Ejabberd instance can serve multiple XMPP domains. This plugin collects metrics
for one such instance.

##### Metrics related to user activity
The following metrics relate to Client-To-Server(C2S) activity. They are reported for
each collection interval and do not accumulate, i.e., they start at zero in the beginning
of the interval.

- `user_iqs_sent` Tags: `dev`, `op`

- `user_iqs_received` Tags: `dev`, `op`

- `user_messages_sent` Tags: `dev`, `op`

- `user_messages_received` Tags: `dev`, `op`

- `user_presences_sent` Tags: `dev`, `op`

- `user_presences_received` Tags: `dev`, `op`

- `offline_messages_sent` Tags: `dev`, `op`

##### Metrics related to S2S activity
The following metrics relate to Server-To-Server(S2S) activity. They are reported for
each collection interval and do not accumulate, i.e., they start at zero in the beginning
of the interval.

- `s2s_iqs_sent` Tags: `dev`, `op`

- `s2s_iqs_received` Tags: `dev`, `op`

- `s2s_messages_sent` Tags: `dev`, `op`

- `s2s_messages_received` Tags: `dev`, `op`

- `s2s_presences_sent` Tags: `dev`, `op`

- `s2s_presences_received` Tags: `dev`, `op`


##### Other metrics
The following metrics accumlate, that is, they are not reset to zero in the beginning
of the collection interval.

- `online_users` Tags: `dev`, `op`

- `registered_users` Tags: `dev`, `op`

- `unknown_packets` Tags: `dev`, `op`
    * **Note**: This metric is used to detect misuse of the XMPP protocol, and should not
    be triggered. The different types of packets should all be caught by the *user_* and
    *s2s_* metrics.

### Notifications

The plugin will send a notification to WombatOAM when something unexpected occurs,
for example if a message is sent to the Ejabberd plugin main process which it
does not recognise.

### Configuration options

None.

[ejabberd_docs]: https://github.com/processone/ejabberd/
[xmpp_spec]: https://xmpp.org/rfcs/rfc3920.html

<!--
### Usage

#### Resource use

(Estimate on the resource use)

#### Stopping monitoring

(Consequences of switching off the plugin; what will stop working in WombatOAM)
-->
