## phoenix plugin

### Description

The `phoenix` plugin reports metrics from requests performed to the endpoints
defined in the `phoenix` application. The plugin exposes fine-grain metrics to
give insight into your Phoenix application. The plugin captures the number of
requests and the average response time for each registered endpoint, HTTP method
(e.g. HTTP `GET`) and HTTP status code (e.g. HTTP `200`).

### Applications it depends on

`phoenix` and `cowboy`

The plugin only works with Phoenix versions 1.x that use Cowboy 0.x or 1.x
versions.

### Modules

`wombat_plugin_phoenix`

### Reports

#### Metrics reported

**Phoenix: Miscellaneous** category

- `Connected channels` Number of connected PubSub channels
  Tags: `dev`, `op`.

- `Open sockets` Number of open sockets
  Tags: `dev`, `op`.


**Phoenix: Request Count** category: these metrics show the number of all
requests and requests performed with a certain HTTP result code or with a
certain method and endpoint.

- `All requests`
  Tags: `dev`, `op`.

- `HTTP STATUS-CODE`
  Tags: `dev`, `op`.

- `[HTTP-METHOD] /ENDPOINT`
  Tags: `dev`.

- `[HTTP-METHOD]`
  Tags: `dev`.

**Phoenix: Response Time [ms]** category: these metrics show the average
response time of all requests and requests performed with a certain HTTP result
code or with a certain method and endpoint.

- `Average duration of all requests`
  Tags: `dev`, `op`.

- `Avg. STATUS-CODE`
  Tags: `dev`, `op`.

- `Avg. [HTTP-METHOD] /ENDPOINT`
  Tags: `dev`.

- `Avg. [HTTP-METHOD]`
  Tags: `dev`.

Where `HTTP-METHOD` is one of `GET`, `HEAD`, `POST`, `PUT`, `DELETE`, `TRACE`,
`OPTIONS`, `CONNECT`, `PATCH`; `ENDPOINT` is one of the endpoints defined
through Phoenix; and `STATUS-CODE` is one of the official status codes (`100`,
`101`, `102`, `200`, `201`, `202`, `203`, `204`, `205`, `206`, `207`, `208`,
`226`, `300`, `301`, `302`, `303`, `304`, `305`, `306`, `307`, `308`, `400`,
`401`, `402`, `403`, `404`, `405`, `406`, `407`, `408`, `409`, `410`, `411`,
`412`, `413`, `414`, `415`, `416`, `417`, `418`, `421`, `422`, `423`, `424`,
`426`, `429`, `431`, `451`, `500`, `501`, `502`, `503`, `504`, `505`, `506`,
`507`, `508`, `510`, `511`); one of RESTful error responses (`103`, `420`,
`450`, `498`, `499`, `509`, `530`); one of Internet Information Services
responses (`440`, `449`, `451`); one of NGINX responses (`444`, `495`, `496`,
`497`, `499`) or one of CloudFlare responses (`520`, `521`, `522`, `523`, `524`,
`525`, `526`).
