## Poolboy plugin

This plugin monitors the pools managed by [Poolboy][poolboy]. The plugin exposes
health metrics about the pools, sends early wanring signs as notifications, and
raises an alarm when a pool turns into a critical state.

### Description

The plugin is based on Poolboy's concepts. The status of a pool is a key
property, which can be:

- `ready` When the number of workers are less than or equal to the initial `Size`
  parameter. `Size` refers to the pool size initially configured.

- `overflow` When the number of workers are greater than the pool `Size` but
  less than the `Size + MaxOverFlow`. `MaxOverflow` refers to the maximum number
  of workers created if pool is empty.

- `full` When the number of workers are equal to the `Size + MaxOverflow`.

### Applications it depends on

`poolboy`

The plugin only works with version 1.x.

### Modules

`wombat_plugin_poolboy.erl`

### Reports

The plugin reports metrics, a notification, and an alarm.

##### Metrics

Each pool is depicted by the following two metrics, which are gauges:

- `Number of available workers for POOL` The number of workers can be checked out.
  Tags: `dev`.

- `Percentage of running workers for POOL` The utilisation of the pool.
  Calculated as follows: `RunningWorkerCount * 100 / Size`.
  Tags: `dev`, `op`.

##### Notification

`Pool is overloaded` When the workers launched initially got used and additional
workers have been launched. This happens when the pool transits into `overflow`
state, by leaving `ready` state.

##### Alarm

An alarm is raised when a pool becomes `full`: all workers are used and no more
workers can be launched.

Please find the detailed alarm description in the
[Alarms documentation][alarmsdoc].

### Configuration options

None.

[poolboy]: https://github.com/devinus/poolboy.git
[alarmsdoc]: ../alarms.md#poolboy
