## rabbitmq alarms plugin

### Description

The `rabbitmq_alarms` plugin allows to monitor the alarms raised by a RabbitMQ node.
There are three types of alarms:
 - memory alarm - It is raised when `vm_memory_high_watermark` is reached.
   It specifies a memory limit for RabbitMQ server at which it blocks publishers and raises memory alarms.
   See more details in [documentation](https://www.rabbitmq.com/memory.html).
 - disk alarm - It is raised when disk space used by RabbitMQ is above specified limit.
   Also all publishers are block, until space is available again.
   See more details in [documentation](https://www.rabbitmq.com/disk-alarms.html).
 - file descriptors alarm - The file handlers are used for opening files and TCP connections.
   If the are too many file descriptors used, alarm is raised.
   See more details in [documentation](https://www.rabbitmq.com/networking.html#open-file-handle-limit).

The first two alarms use the `rabbit_alarm` module, which basically allows to subscribe for the alarm events.
So they are implemented in a reactive way.
However, it is not possible to subscribe for the latter event.
It has to be checked manually.
Therefor there is a timer, which triggers checking the state of the alarm using `rabbit_alarm:get_alarms()` function.
The interval is configurable.

### Supported versions.

Official stable Rabbit releases newer than 2.3.0 are supported.

### Applications it depends on

`rabbit`

### Modules

- `wombat_plugin_rabbitmq_alarms`

### Configuration options

* `file_handles_poll_interval`: Defines the interval in milliseconds between subsequent queries to RabbitMQ if file_handle alarm is raised.
  Default value: `10000` - 10 seconds.

#### Example wombat.config entry

```erlang
%% Set the static queues
{set, wo_plugins, plugins, rabbitmq_alarms, file_handles_poll_inteval, 10000}.

```

### Reports

This plugin reports the following alarms:
 - `rmq_memory_high_watermark`
 - `rmq_disk_limit`
 - `rmq_file_descriptor_limit`
