## rabbitmq channel messages plugin

### Description

The `rabbitmq_channel_messages` plugin currently provides the ability to monitor message rates for individual, active channels. When enabled, this plugin will acquire all active channels from the managed rabbit node and based on its configuration, it generates corresponding message rate metrics for each acquired channel.

All channel metric names follow the following format;

**\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate \<TYPE\> ~ (<\METRIC-PERIOD\>s average)**

where:

**`<CHANNEL-NAME>`** is the native acquired RabbitMQ channel name,

**`<VHOST>`** is the RabbitMQ VHost the channel belongs to,

**`<TYPE>`** is one of

- publish
- confirm
- unroutable
- get
- get no ack
- deliver
- deliver no ack
- redeliver
- ack
- deliver get

**`<METRIC-PERIOD>`** is 60 (seconds) by default, but can be changed through the configuration;

Example of a channel metric would be: `192.168.1.209:55605 -> 192.168.1.211:5672 (4)~/~message rate publish~(60s average)`.



### Supported versions.

All official 3.7 releases are supported and tested.

### Applications it depends on

`rabbit`

### Modules

- `wombat_plugin_rabbitmq_channel_messages`
- `wombat_plugin_rabbitmq_metrics`

### Configuration options

* `metric_period`: specifies the granularity of the samples in milliseconds. It is recommended to set it to a multiple of 5000. The minimum value is 5000. When set to a lower value, it will be ignored and 5000 will be used instead. The default value is 60000, that is 60 seconds.

#### Example wombat.config entry

```erlang
%% Change the metric period
{set, wo_plugins, plugins, rabbitmq_channel_messages, metric_period, 5000}.

```

### Metrics reported

If the plugin is restarted, old metrics for non-existing channels are removed.

#### Channel message rate metrics:

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate get ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of Basic.get operations on **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate get no ack ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of Basic.get operations with auto acknowledgement on **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate deliver ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of messages delivered through **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate deliver no ack ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of messages delivered through **\<CHANNEL-NAME\>** with auto acknowledgement in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate redeliver ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of messages redelivered through **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate ack ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of message acknowledgements received for delivered messages in **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate deliver get ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of messages delivered with Basic.get operations through **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate publish ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of messages published to **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate confirm ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of publish confirms sent from **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds.

* **\<CHANNEL-NAME\> ~ \<VHOST\> ~ message rate unroutable ~ (<\METRIC-PERIOD\>s average)**
  Tags: `dev`, `op`

  The average rate of messages sent through **\<CHANNEL-NAME\>** in the last **\<METRIC-PERIOD\>** seconds that could not be routed to any queue.
