# Getting started with WombatOAM

## Prerequisites

Before installing WombatOAM, ensure that the machine meets the prerequisites.
The following is required before installing WombatOAM:

- A UNIX operating system (WombatOAM has been tested on Linux and OS X)
- Erlang 17.5 or later installed for running WombatOAM, the managed nodes can
be as old as R14.
- OpenSSL and libcrypto (already present on Mac OS X)

## Installing WombatOAM

To install WombatOAM on your computer, retrieve the current WombatOAM package and run
the installation script.

<ol class="ShellSteps">
  <li>
    <p>Extract the WombatOAM package and go inside directory:</p>
    <pre>tar xfz wombat-[VERSION].tar.gz</pre>
    <pre>cd wombat-[VERSION]</pre>
  </li>
  <li>
    <p>Execute the following command:</p>
    <pre>./wombat install</pre>
  </li>
</ol>

If you already have a WombatOAM installation follow the instructions in the "Upgrading WombatOAM"
chapter.

## Installing WombatOAM on Windows

Currently on Windows only running it inside Docker is supported. Please get in touch
with us if you need native Windows support.

<div style="page-break-after:always;"></div>

!INCLUDE "parts/upgrade-howto.md"

## The WombatOAM web dashboard

To access the web dashboard, go to `http://localhost:8080` in your browser.
Log in with the following details:

* **Name:** admin
* **Password:** admin

## Running WombatOAM

The command `./wombat start` will start WombatOAM automatically. You can
use the following commands to manipulate WombatOAM:

<div class="CodeRay" style="page-break-inside:avoid;">
<pre>
./wombat start  # start WombatOAM
./wombat stop   # stop WombatOAM
./wombat start_script # the OTP release start script
</pre>
</div>

The env variable WOMBAT_LICENSE can be used by WombatOAM to read the license 
text, this is useful when doing continuous redeployments.

To check whether WombatOAM is already running, navigate your browser to
the WombatOAM web dashboard on `http://localhost:8080`.

## Running inside containers using Docker

You should have access already to the WombatOAM Docker image, if not, please get
in touch with us.

1. Import the image locally by running the following command, it will show you the tag of the image which is used to start the container:
```
docker load --input wombat_<version>.image.tar
```
2. Start the container and expose the dashboard port. By defining an environment variable we can tell Wombat's webserver to listen on all interfaces:
```
docker run -it -p 8080:8080 -e WOMBAT_NODENAME=wombat@0.0.0.0 wombat:<version>
```
3. Navigate to `localhost:8080` in your browser

If you start WombatOAM this way, your container will have no access to other
Erlang nodes running on your machine, only the `wombat@127.0.0.1` node will be accessible. We suggests setting up a docker-compose.yml file including your application.
For testing purposes you can connect to the container using `docker exec -it $CONTAINER_ID bash` and
start an Erlang node manually. Examples can be found in the next chapters.

Please refer to the manual's "Configuring WombatOAM for servers and containers" chapter
 for more information.

## Running on Amazon AWS

We build AMIs from Wombat. Please get in touch at wombat@erlang-solutions.com if you have no access to them.

Please check the Wombat-Manual.pdf or the html documentation "Using the official AMI containing WombatOAM" section.


## Using WombatOAM

To see how WombatOAM handles nodes, you can let WombatOAM monitor itself:

1. Select the **Topology** tab and click **Add Node**.
2. Enter the following:
	- **Node name**: `wombat@127.0.0.1`
	- **Cookie**: `wombat`
3. Click the **Add node** button.

The WombatOAM node should come up in a few seconds. If it doesn't, check the
following log file for details: `_build/default/rel/wombat/log/wombat@127.0.0.1/wombat.log`

The following chapter will help you to get to know WombatOAM.
