#!/usr/bin/env escript
%% -*- erlang -*-
%%! -s inets start -name restore_backup@127.0.0.1

-define(W(Fmt, Args), io:format(Fmt, Args)).

main([]) ->
    ?W("Usage: ~s BackupFile WombatNode [Cookie]~n", [?FILE]);
main([BackupFile, NodeStr]) ->
    main([BackupFile, NodeStr, "wombat"]);
main([BackupFile, NodeStr, CookieStr]) ->
    Node = list_to_atom(NodeStr),
    Cookie = list_to_atom(CookieStr),
    erlang:set_cookie(Node, Cookie),
    case net_kernel:connect_node(Node) of
        true ->
            ok;
        _Error ->
            ?W("Wombat expected to be running as: ~p~n", [Node]),
            ?W("If your instance uses a different cookie (for example: mycookie), set it by:~n"
               "~s ~s mycookie~n", [?FILE, BackupFile]),
            halt(1)
    end,
    RestoreOpts = [{default_op, recreate_tables}],
    case rpc:call(Node, mnesia, restore, [BackupFile, RestoreOpts]) of
        {atomic, _} ->
            ?W("Mnesia successfully restored.~n", []);
        Error ->
            ?W("Mnesia restore failed with: ~p~n", [Error]),
            halt(1)
    end,
    ok.
