#!/usr/bin/env python3

# This script changes the default Wombat password and adds the specified nodes. 

import re
import sys
import requests
import json
import logging
import argparse
from requests.auth import HTTPBasicAuth

def change_default_password(password):
    url = "http://localhost:8080/api/users/change_password"
    data = {
        "password": password
    }
    data = json.dumps(data)
    header = {"Content-type": "application/json"}
    try:
        resp = requests.post(url, headers=header, data=data, auth=HTTPBasicAuth('admin','admin'))
        if resp.status_code == 200:
            print("Password was changed, now use admin/" + password)
        else:
            print("not able to change the password " + str(resp))
    except Exception as e:
        print("not able to change the password " + str(e))

def add_node(user, password, nodeId, cookie, url):
    header = {"Content-type": "application/json"}
    data = {"name": nodeId, "cookie":  cookie}
    data = json.dumps(data)
    try:
        resp = requests.post(url, headers=header, data=data, auth=HTTPBasicAuth(user, password))
        if resp.status_code == 200:
            print(nodeId + " was added succesfully")
        else:
            print("There was an error while adding the node: " + str(resp))
    except Exception as e:
        print("error: " + str(e))

def add_nodes(file, user, password):
    with open(file) as f:
        jsondata = json.load(f)
    url = "http://localhost:8080/api/topo/action/add-node"
    header = {"Content-type": "application/json"}
    for node in jsondata:
        add_node(user, password, node["node"], node["cookie"], url)

def main():
    parser = argparse.ArgumentParser(description='Headless Wombat')

    subparsers = parser.add_subparsers(help='commands', dest='cmd')
    password_parser = subparsers.add_parser('change_password', help='Change the default password')
    password_parser.add_argument('--password', metavar='Password', required=True, dest='password', help='A password should consist of letters and numbers (without special characters)')

    nodes_parser = subparsers.add_parser('add_nodes', help='Add nodes to wombat')
    nodes_parser.add_argument('--file', metavar='Json File', required=True, dest='file', help='The Json file containing the list of nodes to add')
    nodes_parser.add_argument('--username', metavar='Username', required=True, dest='username', help='The username: admin is the default')
    nodes_parser.add_argument('--password', metavar='Password', required=True, dest='password', help='The password')
    
    node_parser = subparsers.add_parser('add_node', help='add one node to wombat')
    node_parser.add_argument('--node', metavar='Node', required=True, dest='node',  help='A node name')
    node_parser.add_argument('--cookie', metavar='Cookie', required=True, dest='cookie', help='The node cookie')
    node_parser.add_argument('--username', metavar='Username', required=True, dest='username', help='The username: admin is the default')
    node_parser.add_argument('--password', metavar='Password', required=True, dest='password', help='The password')

    node_parser = subparsers.add_parser('add_node_and_discover', help='add a node to wombat and discover its neighbours')
    node_parser.add_argument('--node', metavar='Node', required=True, dest='node',  help='A node name')
    node_parser.add_argument('--cookie', metavar='Cookie', required=True, dest='cookie', help='The node cookie')
    node_parser.add_argument('--username', metavar='Username', required=True, dest='username', help='The username: admin is the default')
    node_parser.add_argument('--password', metavar='Password', required=True, dest='password', help='The password')
    
    results = parser.parse_args()

    if len(sys.argv) < 2:
        help(parser)

    if results.cmd == "change_password":
        password = results.password
        change_default_password(password)
    elif results.cmd == "add_nodes":
        file = results.file
        username = results.username
        password = results.password
        print("adding Nodes..")
        add_nodes(file, username, password)
    elif results.cmd == "add_node":
        username = results.username
        password = results.password
        node = results.node
        cookie = results.cookie
        url = "http://localhost:8080/api/topo/action/add-node"
        add_node(username, password, node, cookie, url)
    elif results.cmd == "add_node_and_discover":
        username = results.username
        password = results.password
        node = results.node
        cookie = results.cookie
        url = "http://localhost:8080/api/topo/action/add-node-and-disc"
        add_node(username, password, node, cookie, url)

def help(parser):    
    subparsers_actions = [
    action for action in parser._actions 
    if isinstance(action, argparse._SubParsersAction)]
    # there will probably only be one subparser_action,
    # but better save than sorry
    for subparsers_action in subparsers_actions:
     # get all subparsers and print help
      for choice, subparser in subparsers_action.choices.items():
        print("Command '{}'".format(choice))
        print(subparser.format_help())
    print("example of a json file:")
    print("[{\"node\" : \"test@127.0.0.1\",\"cookie\" : \"test\"},{\"node\" : \"test1@127.0.0.1\",\"cookie\" : \"test\"}]")

main()